==> esp32c3-0.3.0.crate: esp32c3-0.3.0/src/hmac/set_message_end.rs <==
#[doc = "Register `SET_MESSAGE_END` writer"]
pub struct W(crate::W<SET_MESSAGE_END_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SET_MESSAGE_END_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SET_MESSAGE_END_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SET_MESSAGE_END_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SET_TEXT_END` writer - Start hardware padding."]
pub struct SET_TEXT_END_W<'a> {
    w: &'a mut W,
}
impl<'a> SET_TEXT_END_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
impl W {
    #[doc = "Bit 0 - Start hardware padding."]
    #[inline(always)]
    pub fn set_text_end(&mut self) -> SET_TEXT_END_W {
        SET_TEXT_END_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Process control register 3.\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_message_end](index.html) module"]
pub struct SET_MESSAGE_END_SPEC;
impl crate::RegisterSpec for SET_MESSAGE_END_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [set_message_end::W](W) writer structure"]
impl crate::Writable for SET_MESSAGE_END_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SET_MESSAGE_END to value 0"]
impl crate::Resettable for SET_MESSAGE_END_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/hmac/set_message_end.rs <==
#[doc = "Register `SET_MESSAGE_END` writer"]
pub struct W(crate::W<SET_MESSAGE_END_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SET_MESSAGE_END_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SET_MESSAGE_END_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SET_MESSAGE_END_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SET_TEXT_END` writer - Start hardware padding."]
pub struct SET_TEXT_END_W<'a> {
    w: &'a mut W,
}
impl<'a> SET_TEXT_END_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
        self.w
    }
}
impl W {
    #[doc = "Bit 0 - Start hardware padding."]
    #[inline(always)]
    pub fn set_text_end(&mut self) -> SET_TEXT_END_W {
        SET_TEXT_END_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Process control register 3.\n\nThis register you can [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [set_message_end]
(index.html) module"]
pub struct SET_MESSAGE_END_SPEC;
impl crate::RegisterSpec for SET_MESSAGE_END_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [set_message_end::W]
(W) writer structure"]
impl crate::Writable for SET_MESSAGE_END_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SET_MESSAGE_END to value 0"]
impl crate::Resettable for SET_MESSAGE_END_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
